Enlightenment CVS committal

Author  : tsauerbeck
Project : e17
Module  : apps/e

Dir     : e17/apps/e/src/modules/ibar


Modified Files:
        e_mod_main.c 


Log Message:
Edjes now use 'edj' as the filename extension
===================================================================
RCS file: /cvsroot/enlightenment/e17/apps/e/src/modules/ibar/e_mod_main.c,v
retrieving revision 1.21
retrieving revision 1.22
diff -u -3 -r1.21 -r1.22
--- e_mod_main.c        21 Mar 2005 22:42:47 -0000      1.21
+++ e_mod_main.c        22 Mar 2005 19:30:32 -0000      1.22
@@ -428,8 +428,8 @@
    o = edje_object_add(ibb->evas);
    ibb->bar_object = o;
    edje_object_file_set(o,
-                       /* FIXME: "default.eet" needs to come from conf */
-                       e_path_find(path_themes, "default.eet"),
+                       /* FIXME: "default.edj" needs to come from conf */
+                       e_path_find(path_themes, "default.edj"),
                        "modules/ibar/main");
    evas_object_show(o);
 
@@ -437,8 +437,8 @@
    ibb->overlay_object = o;
    evas_object_layer_set(o, 1);
    edje_object_file_set(o,
-                       /* FIXME: "default.eet" needs to come from conf */
-                       e_path_find(path_themes, "default.eet"),
+                       /* FIXME: "default.edj" needs to come from conf */
+                       e_path_find(path_themes, "default.edj"),
                        "modules/ibar/follower");
    evas_object_show(o);
 
@@ -611,8 +611,8 @@
    evas_object_intercept_move_callback_add(o, _ibar_icon_cb_intercept_move, 
ic);
    evas_object_intercept_resize_callback_add(o, 
_ibar_icon_cb_intercept_resize, ic);
    edje_object_file_set(o,
-                       /* FIXME: "default.eet" needs to come from conf */
-                       e_path_find(path_themes, "default.eet"),
+                       /* FIXME: "default.edj" needs to come from conf */
+                       e_path_find(path_themes, "default.edj"),
                        "modules/ibar/icon");
    evas_object_show(o);
 
@@ -630,8 +630,8 @@
    evas_object_intercept_move_callback_add(o, _ibar_icon_cb_intercept_move, 
ic);
    evas_object_intercept_resize_callback_add(o, 
_ibar_icon_cb_intercept_resize, ic);
    edje_object_file_set(o,
-                       /* FIXME: "default.eet" needs to come from conf */
-                       e_path_find(path_themes, "default.eet"),
+                       /* FIXME: "default.edj" needs to come from conf */
+                       e_path_find(path_themes, "default.edj"),
                        "modules/ibar/icon_overlay");
    evas_object_show(o);
 




-------------------------------------------------------
This SF.net email is sponsored by: 2005 Windows Mobile Application Contest
Submit applications for Windows Mobile(tm)-based Pocket PCs or Smartphones
for the chance to win $25,000 and application distribution. Enter today at
http://ads.osdn.com/?ad_id=6882&alloc_id=15148&op=click
_______________________________________________
enlightenment-cvs mailing list
enlightenment-cvs@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-cvs

Reply via email to